// Package model provides model abstraction for document service
package model

import (
	"context"

	document "gitlab.mashroom.com/mashroom/backend/document/api"

	"gitlab.mashroom.com/mashroom/backend/common/api/generic/query"
	"go.mongodb.org/mongo-driver/bson/primitive"
)

// Repository provides persistent operations for document service
type Repository interface {
	Migrate(ctx context.Context) error
	DocumentGetByID(ctx context.Context, id primitive.ObjectID) (*Document, error)
	DocumentGetByFileUserPropertyType(
		ctx context.Context,
		file, user, property string,
		typ document.DocumentType,
		removed bool,
	) (*Document, error)
	DocumentCreate(ctx context.Context, document *Document) error
	DocumentUpdate(ctx context.Context, document *Document) error
	DocumentRemove(ctx context.Context, id primitive.ObjectID) error
	DocumentCount(ctx context.Context, file string) (int64, error)
	DocumentFilter(ctx context.Context, filter *query.QueryParams) ([]*Document, int64, error)
}
