package model

import (
	"time"

	document "gitlab.mashroom.com/mashroom/backend/document/api"
	"go.mongodb.org/mongo-driver/bson/primitive"
)

// Document represents user-managed document (e.g. photo of user, bill or proof of identity)
type Document struct {
	Expiration         time.Time              `bson:"expiration"`
	CreatedAt          time.Time              `bson:"created_at"`
	UpdatedAt          time.Time              `bson:"updated_at"`
	User               string                 `bson:"user"`
	Property           string                 `bson:"property"`
	File               string                 `bson:"file"`
	Name               string                 `bson:"name"`
	Mime               string                 `bson:"mime"`
	Description        string                 `bson:"description"`
	SignatureRequestID string                 `bson:"signature_request_id"`
	Code               string                 `bson:"code"`
	ProductID          string                 `bson:"product_id"`
	OriginalFile       string                 `bson:"original_file"`
	Sha256             []byte                 `bson:"sha256"`
	Amount             float64                `bson:"amount"`
	Size               int64                  `bson:"size"`
	Type               document.DocumentType  `bson:"type"`
	State              document.DocumentState `bson:"state"`
	ID                 primitive.ObjectID     `bson:"_id,omitempty"`
	Signed             bool                   `bson:"signed"`
	Removed            bool                   `bson:"removed"`
}
