// Package v2 provides migration to version 2 of mongo repository
package v2

import (
	"context"

	"gitlab.mashroom.com/mashroom/backend/document/internal/model"
	"go.mongodb.org/mongo-driver/bson"
	"go.mongodb.org/mongo-driver/mongo"
)

// Up applies v2 migration
func Up(ctx context.Context, db *mongo.Database) error {
	col := db.Collection("documents")

	cur, err := col.Find(ctx, bson.M{"user": ""})
	if err == mongo.ErrNoDocuments {
		return nil
	}

	if err != nil {
		return err
	}

	var m model.Document

	for cur.Next(ctx) {
		err = cur.Decode(&m)
		if err != nil {
			return err
		}

		var o model.Document

		err = col.FindOne(ctx, bson.M{"property": m.Property, "user": bson.M{"$ne": ""}}).Decode(&o)
		if err == mongo.ErrNoDocuments {
			continue
		}

		if err != nil {
			return err
		}

		m.User = o.User

		_, err = col.ReplaceOne(ctx, bson.M{"_id": m.ID}, m)
		if err != nil {
			return err
		}
	}

	return nil
}
