// Package v3 provides migration to version 3 of mongo repository
package v3

import (
	"context"
	"time"

	"go.mongodb.org/mongo-driver/bson"
	"go.mongodb.org/mongo-driver/mongo"
)

// Up applies v3 migration
func Up(ctx context.Context, db *mongo.Database) error {
	col := db.Collection("documents")

	_, err := col.UpdateMany(ctx, bson.M{}, bson.M{
		"$rename": bson.M{
			"inactive": "removed",
		},
	})
	if err != nil {
		return err
	}

	_, err = col.UpdateMany(ctx, bson.M{"removed": bson.M{"$ne": true}}, bson.M{
		"$set": bson.M{
			"removed": false,
		},
	})
	if err != nil {
		return err
	}

	_, err = col.UpdateMany(ctx, bson.M{}, bson.M{
		"$set": bson.M{
			"updated_at": time.Now(),
		},
	})
	if err != nil {
		return err
	}

	return nil
}
