package service

import (
	"context"

	document "gitlab.mashroom.com/mashroom/backend/document/api"
	"gitlab.mashroom.com/mashroom/backend/document/internal/model"
	"google.golang.org/protobuf/types/known/timestamppb"
)

func (srv *serviceImpl) renderDocuments(
	ctx context.Context,
	ms []*model.Document,
) (docs []*document.Document, err error) {
	for _, m := range ms {
		var doc *document.Document

		doc, err = srv.renderDocument(ctx, m)
		if err != nil {
			return
		}

		docs = append(docs, doc)
	}

	return
}

func (srv *serviceImpl) renderDocument(ctx context.Context, m *model.Document) (*document.Document, error) {
	var file *document.File

	if len(m.Sha256) == 0 && m.File != "" {
		f, _, err := srv.config.Storage.FileGetByIDSize(ctx, m.File, document.ImageSize_ORIGINAL, nil)
		if err != nil {
			return nil, err
		}

		m.Sha256 = f.GetSha256()
		m.Name = f.GetName()
		m.CreatedAt = f.GetCreatedAt().AsTime()
		m.Size = f.GetSize()
		m.Mime = f.GetMime()
	}

	created := timestamppb.New(m.CreatedAt)

	if m.File != "" {
		file = &document.File{
			Id:        m.File,
			Name:      m.Name,
			Mime:      m.Mime,
			CreatedAt: created,
			Size:      m.Size,
			Sha256:    m.Sha256,
		}
	}

	return &document.Document{
		Id:                 m.ID.Hex(),
		Type:               m.Type,
		User:               m.User,
		Property:           m.Property,
		File:               file,
		Signed:             m.Signed,
		SignatureRequestId: m.SignatureRequestID,
		Expiration:         timestamppb.New(m.Expiration),
		State:              m.State,
		Code:               m.Code,
		Amount:             m.Amount,
		Description:        m.Description,
		CreatedAt:          created,
		UpdatedAt:          timestamppb.New(m.UpdatedAt),
		Removed:            m.Removed,
		ProductId:          m.ProductID,
	}, nil
}
