// Package storage provides file storage abstraction for document service
package storage

import (
	"context"
	"io"

	document "gitlab.mashroom.com/mashroom/backend/document/api"
)

// Repository provides persistent operations over file storage
type Repository interface {
	Migrate(ctx context.Context) error
	FileGetByIDSize(
		ctx context.Context,
		id string,
		size document.ImageSize,
		vairant *document.ImageVariant,
	) (file *document.File, path string, err error)
	FileSave(ctx context.Context, file *document.File, data io.Reader) (path string, err error)
	FileUpdate(ctx context.Context, file *document.File) (err error)
	FileDelete(ctx context.Context, id string) (err error)
	FileCleanSize(ctx context.Context, size document.ImageSize) (err error)
}
